==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/BehaviorPreferences/ts/BehaviorPreferences_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>BehaviorPreferences</name>
    <message>
        <location filename="../BehaviorPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>Grafikansicht</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Behavior</source>
        <translation>Verhalten</translation>
    </message>
</context>
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+48"/>
        <source>Double-Click</source>
        <translation>Doppelklick</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Double-click to edit text</source>
        <translation>Doppelklick verwenden, um Text zu bearbeiten</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Double-click to edit hatch</source>
        <translation>Doppelklick verwenden, um Schraffur zu bearbeiten</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Double-click on block reference opens block</source>
        <translation>Doppelklick auf Blockreferenz öffnet Block</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Right double-click to reset</source>
        <translation>Rechts-Doppelklick zum Zurücksetzen</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Blocks</source>
        <translation>Blöcke</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Select block references together with attributes</source>
        <translation>Blockreferenzen zusammen mit ihren Attributen selektieren</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Hide attributes when block references are hidden</source>
        <translation>Attribute mit Blockreferenz ausblenden</translation>
    </message>
    <message>
        <location line="-85"/>
        <source>Right-Click</source>
        <translation>Rechtsklick</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Right-click to deselect entities</source>
        <translation>Rechtsklick zum Deselektieren von Objekten</translation>
    </message>
    <message>
        <source>Right-click on entity shows context menu</source>
        <translation type="vanished">Rechtsklick auf Objekt zeigt Kontextmenü</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Double-click to select contour</source>
        <translation>Doppelklick selektiert Kontour</translation>
    </message>
    <message>
        <source>Block Selection</source>
        <translation type="vanished">Blockselektion</translation>
    </message>
    <message>
        <source>Select block reference with attribute</source>
        <translation type="obsolete">Wählen Sie die Blockreferenz mit Attribut</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Cursor Range</source>
        <translation>Zeigerreichweite</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Cursor range for snap:</source>
        <translation>Zeigerreichweite für Fangen:</translation>
    </message>
    <message>
        <location line="+54"/>
        <source>Cursor range for picking entities:</source>
        <translation>Zeigerreichweite für Objektwahl:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/BehaviorPreferences/ts/BehaviorPreferences_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>BehaviorPreferences</name>
    <message>
        <location filename="../BehaviorPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>Grafikansicht</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Behavior</source>
        <translation>Verhalten</translation>
    </message>
</context>
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+48"/>
        <source>Double-Click</source>
        <translation>Doppelklick</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Double-click to edit text</source>
        <translation>Doppelklick verwenden, um Text zu bearbeiten</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Double-click to edit hatch</source>
        <translation>Doppelklick verwenden, um Schraffur zu bearbeiten</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Double-click on block reference opens block</source>
        <translation>Doppelklick auf Blockreferenz öffnet Block</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Right double-click to reset</source>
        <translation>Rechts-Doppelklick zum Zurücksetzen</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Blocks</source>
        <translation>Blöcke</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Select block references together with attributes</source>
        <translation>Blockreferenzen zusammen mit ihren Attributen selektieren</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Hide attributes when block references are hidden</source>
        <translation>Attribute mit Blockreferenz ausblenden</translation>
    </message>
    <message>
        <location line="+126"/>
        <source>Highlight entity within range</source>
        <translation>Objekt in Reichweite hervorheben</translation>
    </message>
    <message>
        <source>Keyboard Operations</source>
        <translation type="vanished">Tastatur Operationen</translation>
    </message>
    <message>
        <source>Angle step for rotating:</source>
        <translation type="vanished">Winkelschritt zum Drehen:</translation>
    </message>
    <message>
        <location line="-211"/>
        <source>Right-Click</source>
        <translation>Rechtsklick</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Right-click to deselect entities</source>
        <translation>Rechtsklick zum Deselektieren von Objekten</translation>
    </message>
    <message>
        <source>Right-click on entity shows context menu</source>
        <translation type="vanished">Rechtsklick auf Objekt zeigt Kontextmenü</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Double-click to select contour</source>
        <translation>Doppelklick selektiert Kontour</translation>
    </message>
    <message>
        <source>Block Selection</source>
        <translation type="vanished">Blockselektion</translation>
    </message>
    <message>
        <source>Select block reference with attribute</source>
        <translation type="obsolete">Wählen Sie die Blockreferenz mit Attribut</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Cursor Range</source>
        <translation>Zeigerreichweite</translation>
    </message>
    <message>
        <location line="+109"/>
        <source>Cursor range for snap:</source>
        <translation>Zeigerreichweite für Fangen:</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Cursor range for picking entities:</source>
        <translation>Zeigerreichweite für Objektwahl:</translation>
    </message>
</context>
</TS>
